# pyanp

[![Join the chat at https://gitter.im/pythonanp/Lobby](https://badges.gitter.im/pythonanp/Lobby.svg)](https://gitter.im/pythonanp/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
Python ANP Module and Resources

# Installation
Directly from pypi (this version will be more stable)
```
pip install pyanp
```
or if you want to install the latest greatest:
```
pip install git+https://github.com/wjladams/pyanp.git
```
# Quickstart

[A quickstart guide to basic functionality](quickstart.ipynb)
